pub enum PlotType {
Dot,
Density,
Contour,
Zebra,
Histogram,
}Expand description
Plot type enumeration
This enum can be used to dispatch to different plot implementations.
However, for better type safety and extensibility, prefer using the
Plot trait directly with specific plot types.
Variants
Dot
Dot plot (scatter plot)
Density
Density plot (2D histogram)
Contour
Contour plot
Zebra
Zebra plot
Histogram
Histogram plot